%define major     0
%define libname   %mklibname davix %{major}
%define develname %mklibname davix -d

%define tag R_%(echo %{version} | tr '.' '_' )

%global with_tests 0

Name:				davix
Version:			0.8.7
Release:			%mkrel 4
Summary:			Toolkit for Http-based file management
License:			LGPLv2+
Group:				Networking/Other
URL:				https://davix.web.cern.ch/
# Blessed release tarballs found in https://github.com/cern-fts/davix/releases
Source0:		        https://github.com/cern-fts/davix/releases/download/%{tag}/davix-%{version}.tar.gz
Patch0:			        davix_cmake_minimim_version.patch
# ./packaging/make-dist.sh
# the tar.gz is in the build folder
#main lib dependencies
BuildRequires:                  cmake
BuildRequires:                  doxygen
BuildRequires:                  libxml2-devel
BuildRequires:                  rapidjson
BuildRequires:                  openssl-devel
BuildRequires:                  pkgconfig(libcurl)
# build uses "git apply" to apply a patch to the bundled curl source
BuildRequires:                  git-core
# davix-copy dependencies
BuildRequires:                  pkgconfig(gsoap)
BuildRequires:                  libuuid-devel
# unit tests and abi check
%if 0%{?with_tests}
BuildRequires:                  abi-compliance-checker
%endif


%description
Davix is a toolkit designed for file operations
with Http based protocols (WebDav, Amazon S3, ...).
Davix provides an API and a set of command line tools.

%package -n %{libname}
Summary:			Development files for %{name}
Provides:			%{name}-libs = %{version}-%{release}
Group:				Networking/Other
Provides:			bundled(libneon)

%description -n %{libname}
Davix is a toolkit designed for file operations
with Http based protocols (WebDav, Amazon S3, ...).
Davix provides an API and a set of command line tools.

%package -n %{develname}
Summary:			Development files for %{name}
Provides:			%{name}-devel = %{version}-%{release}
Requires:			%{libname} = %{version}-%{release}
Group:				Networking/Other

%description -n %{develname}
Development files for %{name}. Davix is a toolkit designed for file operations
with Http based protocols (WebDav, Amazon S3, ...).

%package doc
Summary:			Documentation for %{name}
BuildArch:			noarch

%description doc
Documentation and examples for %{name}. Davix is a toolkit designed
for file operations with Http based protocols (WebDav, Amazon S3, ...).

%prep
%autosetup -p1

# remove useless embedded components
rm -rf test/pywebdav/
rm -rf src/libs/rapidjson
rm -rf deps/curl

%build
%cmake \
-DDOC_INSTALL_DIR=%{_pkgdocdir} \
-DENABLE_THIRD_PARTY_COPY=TRUE \
-DENABLE_HTML_DOCS=TRUE \
-DEMBEDDED_LIBCURL:BOOL=FALSE \
-DUNIT_TESTS=TRUE

%cmake_build
pushd build
make doc
popd

%if 0%{?with_tests}
%check
pushd build
make abi-check
ctest -V -T Test
popd
%endif

%install
%cmake_install

%files
%{_bindir}/*
%{_mandir}/man1/*

%files -n %{libname}
%{_libdir}/libdavix.so.%{major}{,.*}
%{_libdir}/libdavix_copy.so.%{major}{,.*}

%files -n %{develname}
%{_libdir}/libdavix.so
%{_libdir}/libdavix_copy.so
%dir %{_includedir}/davix
%{_includedir}/davix/*
%{_libdir}/pkgconfig/*
%{_mandir}/man3/*

%files doc
%{_pkgdocdir}/LICENSE
%{_pkgdocdir}/RELEASE-NOTES.md
%{_pkgdocdir}/html/


%changelog
* Thu Jul 10 2025 mrambo3501 <mrambo3501> 0.8.7-4.mga10
+ Revision: 2252741
- add cmake minimum version patch
+ umeabot <umeabot>
- Mageia 10 Mass Rebuild

* Sun Mar 16 2025 wally <wally> 0.8.7-2.mga10
+ Revision: 2164760
- rebuild for libxml2 2.13.6

* Wed Sep 11 2024 papoteur <papoteur> 0.8.7-1.mga10
+ Revision: 2095025
- new version 0.8.7
- add rapidjson as BR to nor use the bundled one
- add libcurl as BR to not use the bundled one
- mark libneon as bundled

* Wed Oct 11 2023 daviddavid <daviddavid> 0.8.4-1.mga10
+ Revision: 1994362
- new version: 0.8.4

* Mon Oct 03 2022 joequant <joequant> 0.8.3-1.mga9
+ Revision: 1894420
- update to 0.8.3
- update to 0.8.3

* Sun Apr 10 2022 joequant <joequant> 0.8.1-1.mga9
+ Revision: 1848509
- update to 0.8.1
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Sat Oct 02 2021 wally <wally> 0.7.6-2.mga9
+ Revision: 1747860
- rebuild for openssl 3.0.0

* Sun Jul 12 2020 joequant <joequant> 0.7.6-1.mga8
+ Revision: 1605536
- update to 0.7.6

* Tue Apr 28 2020 joequant <joequant> 0.7.5-1.mga8
+ Revision: 1572913
- imported package davix

